/*
   Siag, Scheme In A Grid
   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.
 */

/* These are not declared in calc.h because they will only be called here */
extern void fileio_siag_init(void);
extern void fileio_xls_init(void);
extern void fileio_txt_init(void);
extern void fileio_ps_init(void);
extern void fileio_html_init(void);
extern void fileio_wk1_init(void);
extern void fileio_scm_init(void);
extern void fileio_tbl_init(void);
extern void fileio_latex_init(void);
extern void fileio_abs_init(void);
